==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseOffset/ts/EllipseOffset_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>CircleConcentric</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">距離:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">数:</translation>
    </message>
    <message>
        <source>&amp;Concentric (with Distance)</source>
        <translation type="obsolete">&amp;C 同心円（距離指定）</translation>
    </message>
    <message>
        <source>Draw concentric circle</source>
        <translation type="obsolete">同心円を描画</translation>
    </message>
</context>
<context>
    <name>EllipseConcentric</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">距離:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">数:</translation>
    </message>
</context>
<context>
    <name>EllipseOffset</name>
    <message>
        <location filename="../EllipseOffset.ui" line="+17"/>
        <source>Distance:</source>
        <translation>距離:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translation>数:</translation>
    </message>
    <message>
        <location filename="../EllipseOffsetInit.js" line="+2"/>
        <source>&amp;Parallel Curve (with Distance)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw parallel curve to ellipse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseOffset/ts/EllipseOffset_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CircleConcentric</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">距離:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">数:</translation>
    </message>
    <message>
        <source>&amp;Concentric (with Distance)</source>
        <translation type="obsolete">&amp;C 同心円（距離指定）</translation>
    </message>
    <message>
        <source>Draw concentric circle</source>
        <translation type="obsolete">同心円を描画</translation>
    </message>
</context>
<context>
    <name>EllipseConcentric</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">距離:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">数:</translation>
    </message>
</context>
<context>
    <name>EllipseOffset</name>
    <message>
        <location filename="../EllipseOffset.ui" line="+17"/>
        <source>Distance:</source>
        <translation>距離:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translation>数:</translation>
    </message>
    <message>
        <location filename="../EllipseOffsetInit.js" line="+2"/>
        <source>&amp;Parallel Curve (with Distance)</source>
        <translation>並行曲線（距離指定）</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw parallel curve to ellipse</source>
        <translation>楕円の並行曲線を描く</translation>
    </message>
</context>
</TS>
